# [OpenRazer effects](https://github.com/explodes/openrazer_effects)

A collection of effects to use with [OpenRazer](https://openrazer.github.io/)

## Installation

`pip install openrazer_effects`

## Usage

`openrazer_effects list`
List all effects

`openrazer_run <effect> [--audio-device=<device>]`
Run an effect for a specific audio device.

`openrazer_effects audiolist`
List available audio devices

`openrazer_effects audiotest`
Test capture of available audio devices. Can be crashy!!